@@ -8,11 +8,16 @@ $Id: $
 __authors__ = 'Geoff Davis <geoff@geoffdavis.net>'
 __docformat__ = 'restructuredtext'
 
+from urllib import quote
+from Acquisition import aq_inner
+from Products.CMFPlone.interfaces import IBrowserDefault
+
 from AccessControl import ClassSecurityInfo
 from AccessControl.User import nobody
 import DateTime
 from Products.PageTemplates.Expressions import getEngine, SecureModuleImporter
 from Products.PageTemplates.TALES import CompilerError
+from ZopeUndo.Prefix import Prefix
 
 from Products.Archetypes import public as atapi
 try:
@@ -21,14 +26,15 @@ except ImportError:
     from Products.CMFCore import CMFCorePermissions as permissions
 from Products.CMFCore import Expression
 from Products.CMFCore.utils import getToolByName
+
 from Products.CacheSetup.utils import base_hasattr
 from Products.CacheSetup.config import CACHE_TOOL_ID, PAGE_CACHE_MANAGER_ID
-from Products.CacheSetup.content.interfaces import ICacheRule
+from Products.CacheSetup.interfaces import ICacheRule
 from nocatalog import NoCatalog
 
 header_set_schema = atapi.Schema((
                        atapi.LinesField('cacheStop',
-                                        default=['portal_status_message'],
+                                        default=('portal_status_message','statusmessages'),
                                         widget=atapi.LinesWidget(label='Cache Preventing Request Values',
                                                                  description='Values in the request that prevent caching if present'),
                                         write_permission = permissions.ManagePortal,
@@ -85,7 +91,7 @@ header_set_schema = atapi.Schema((
                                           ),
                        ))
 etag_schema = atapi.Schema((
-                       atapi.StringField('etagComponents',
+                       atapi.LinesField('etagComponents',
                                          default=('member','skin','language','gzip','catalog_modified'),
                                          widget=atapi.MultiSelectionWidget(label='ETag Components',
                                                                            description='Items used to construct the ETag',
@@ -105,7 +111,7 @@ etag_schema = atapi.Schema((
                                          write_permission = permissions.ManagePortal,
                                         ),
                        atapi.LinesField('etagRequestValues',
-                                         default=[],
+                                         default=(),
                                          widget=atapi.LinesWidget(label='ETag Request Values',
                                                                   description='Request values used to construct the ETag'),
                                          write_permission = permissions.ManagePortal,
@@ -218,6 +224,30 @@ class BaseCacheRule(NoCatalog):
         if expression:
             return expression(expr_context)
 
+    def lastDate(self, *dates):
+        if len(dates) == 0:
+            return self.portal_cache_settings.modified()
+        dates = list(dates)
+        timeout = self.getEtagTimeout()
+        if timeout:
+            time = DateTime.DateTime()
+            time = timeout * (int(time.timeTime()/timeout) - 1)
+            time = DateTime.DateTime(time)
+            dates.append(time)
+        dates.sort()
+        return dates[-1]
+
+    def getLastTransactionDate(self, context=None):
+        spec = {}
+        if context is None:
+            context = getToolByName(self, 'portal_url').getPortalObject()
+        path = '/'.join(context.getPhysicalPath())
+        spec['description'] = Prefix(path)
+        lastTransaction = self._p_jar.db().undoInfo(0, 1, spec)
+        if len(lastTransaction) == 0:
+            return DateTime.DateTime(self.Control_Panel.process_start)
+        return DateTime.DateTime(lastTransaction[0]['time'])
+
     def getVaryExpression(self):
         expression = self.getField('varyExpression').get(self)
         if expression:
@@ -256,9 +286,13 @@ class BaseCacheRule(NoCatalog):
         try:
             template = object.unrestrictedTraverse(template_id)
         except (AttributeError, KeyError):
-            template = None # XXX should log the fact that this template can't be found
-        if template and template.ZCacheable_getManagerId() is None:
-            template.ZCacheable_setManagerId(PAGE_CACHE_MANAGER_ID)
+            template = None 
+            # XXX should log the fact that this template can't be found
+        if template is not None:
+            manager_id = getattr(template, 'ZCacheable_getManagerId', None)
+            if manager_id is not None:
+                if manager_id() is None:
+                    template.ZCacheable_setManagerId(PAGE_CACHE_MANAGER_ID)
 
     def _getHeaderSet(self, request, object, view, member):
         stop_items = self.getCacheStop()
@@ -285,7 +319,8 @@ class BaseCacheRule(NoCatalog):
 
     def getHeaderSetVocabulary(self):
         pcs = getToolByName(self, CACHE_TOOL_ID)
-        headers = pcs.getHeaderSets()
+        display_id = pcs.getDisplayPolicy().getId()
+        headers = pcs.getHeaderSets(display_id)
         vocabulary = [('expression', 'Use expression below')] + \
                      [(hs.getId(), hs.Title()) for hs in headers.objectValues()] + \
                      [('None', 'Rule does not apply')]
@@ -293,24 +328,37 @@ class BaseCacheRule(NoCatalog):
         
     def getObjectDefaultView(self, obj):
         """Get the id of an object's default view"""
-        default_view = None
-        if base_hasattr(obj, 'defaultView'):
-            default_view = obj.defaultView(obj.REQUEST)
-        if not default_view and base_hasattr(obj, 'default_view'):
-            default_view = obj.default_view
-        if not default_view:
+        context = aq_inner(obj)
+        browserDefault = IBrowserDefault(context, None)
+        
+        if browserDefault is not None:
             try:
-                view = obj.getTypeInfo().getActionInfo('object/view')['url']
+                return browserDefault.defaultView()
             except AttributeError:
-                view = obj.getTypeInfo().getActionById('view')
-            except ValueError:
-                # no object/view action
-                return None
-            if view.startswith('/'):
-                view = view[1:]
-            default_view = view
-        return default_view
+                # Might happen if FTI didn't migrate yet.
+                pass
 
+        fti = context.getTypeInfo()
+        try:
+            # XXX: This isn't quite right since it assumes the action starts with ${object_url}
+            action = fti.getActionInfo('object/view')['url'].split('/')[-1]
+        except ValueError:
+            # If the action doesn't exist, stop
+            return None
+
+        # Try resolving method aliases because we need a real template_id here
+        if action:
+            action = fti.queryMethodID(action, default = action, context = context)
+        else:
+            action = fti.queryMethodID('(Default)', default = action, context = context)
+
+        # Strip off leading / and/or @@
+        if action and action[0] == '/':
+            action = action[1:]
+        if action and action.startswith('@@'):
+            action = action[2:]
+        return action
+        
     def _addEtagComponent(self, etag, component):
         etag += '|' + str(component).replace(',',';')  # commas are used to separate etags in if-none-match headers
         return etag
@@ -376,7 +424,7 @@ class BaseCacheRule(NoCatalog):
             for rv in req_values:
                 v = request.get(rv, marker)
                 if v is not marker:
-                    etag = self._addEtagComponent(etag, v)
+                    etag = self._addEtagComponent(etag, quote(str(v)))
                 else:
                     etag = self._addEtagComponent(etag, '')
                     
