@@ -8,13 +8,16 @@ __docformat__ = 'restructuredtext'
 
 from AccessControl import ClassSecurityInfo
 from Products.Archetypes import public as atapi
+from Products.CacheSetup.config import PROJECT_NAME
+from nocatalog import NoCatalog
+
 try:
     from Products.CMFCore import permissions
 except ImportError:
     from Products.CMFCore import CMFCorePermissions as permissions
-from Products.CacheSetup.content.interfaces import ICacheToolFolder
+from Products.CacheSetup.interfaces import ICacheToolFolder
 
-class HeaderSetFolder(atapi.OrderedBaseFolder):
+class HeaderSetFolder(NoCatalog, atapi.OrderedBaseFolder):
     """A container for header set objects"""
 
     __implements__ = (atapi.OrderedBaseFolder.__implements__, ICacheToolFolder)
@@ -26,7 +29,7 @@ class HeaderSetFolder(atapi.OrderedBaseFolder):
     allowed_content_types = ('HeaderSet',)
 
     actions = (
-        {'action':      'string:$object_url/cache_setup_config',
+        {'action':      'string:$object_url',
          'category':    'object',
          'id':          'view',
          'name':        'Cache Setup',
@@ -35,9 +38,9 @@ class HeaderSetFolder(atapi.OrderedBaseFolder):
     )
 
     aliases = {
-        '(Default)':    'cache_setup_config',
-        'view' :        'cache_setup_config',
-        'edit' :        'base_edit'
+        '(Default)':    'cache_policy_item_config',
+        'view' :        'cache_policy_item_config',
+        'edit' :        'cache_policy_item_config'
     }
 
-atapi.registerType(HeaderSetFolder)
+atapi.registerType(HeaderSetFolder, PROJECT_NAME)
