@@ -8,13 +8,16 @@ __docformat__ = 'restructuredtext'
 
 from AccessControl import ClassSecurityInfo
 from Products.Archetypes import public as atapi
-from Products.CacheSetup.content.interfaces import ICacheToolFolder
+from Products.CacheSetup.interfaces import ICacheToolFolder
+from Products.CacheSetup.config import PROJECT_NAME
+from nocatalog import NoCatalog
+
 try:
     from Products.CMFCore import permissions
 except ImportError:
     from Products.CMFCore import CMFCorePermissions as permissions
 
-class RuleFolder(atapi.OrderedBaseFolder):
+class RuleFolder(NoCatalog, atapi.OrderedBaseFolder):
     """A container for rule objects"""
 
     __implements__ = (atapi.OrderedBaseFolder.__implements__, ICacheToolFolder)
@@ -26,7 +29,7 @@ class RuleFolder(atapi.OrderedBaseFolder):
     allowed_content_types = ('ContentCacheRule','TemplateCacheRule','PolicyHTTPCacheManagerCacheRule')
 
     actions = (
-        {'action':      'string:$object_url/cache_setup_config',
+        {'action':      'string:$object_url',
          'category':    'object',
          'id':          'view',
          'name':        'Cache Setup',
@@ -35,9 +38,9 @@ class RuleFolder(atapi.OrderedBaseFolder):
     )
 
     aliases = {
-        '(Default)':    'cache_setup_config',
-        'view' :        'cache_setup_config',
-        'edit' :        'base_edit'
+        '(Default)':    'cache_policy_item_config',
+        'view' :        'cache_policy_item_config',
+        'edit' :        'cache_policy_item_config'
     }
 
-atapi.registerType(RuleFolder)
+atapi.registerType(RuleFolder, PROJECT_NAME)
