@@ -1,5 +1,5 @@
 """
-$Id: test_doctests.py 14058 2005-11-18 01:03:05Z dreamcatcher $
+$Id: test_doctests.py 38021 2007-02-17 21:35:09Z witsch $
 """
 
 import os
@@ -18,6 +18,10 @@ CMFTestCase.installProduct('StandardCacheManagers')
 CMFTestCase.installProduct('PolicyHTTPCacheManager')
 CMFTestCase.setupCMFSite()
 
+from zope.testing import doctest
+OPTIONFLAGS = (doctest.ELLIPSIS |
+               doctest.NORMALIZE_WHITESPACE)
+
 class FunctionalTest(CMFTestCase.FunctionalTestCase): pass
 
 def test_suite():
@@ -29,6 +33,7 @@ def test_suite():
         suite.addTest(
             FunctionalDocFileSuite(
             fname,
+            optionflags=OPTIONFLAGS,
             package='Products.PolicyHTTPCacheManager.tests',
             test_class=FunctionalTest))
     return suite
